@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
  * USA.
  */
 
@@ -31,8 +31,9 @@
 
 gboolean
 _glade_single_object_accumulator (GSignalInvocationHint *ihint,
-				  GValue *return_accu,
-				  const GValue *handler_return, gpointer dummy)
+                                  GValue                *return_accu,
+                                  const GValue          *handler_return,
+                                  gpointer               dummy)
 {
   GObject *object = g_value_get_object (handler_return);
   g_value_set_object (return_accu, object);
@@ -42,9 +43,9 @@ _glade_single_object_accumulator (GSignalInvocationHint *ihint,
 
 gboolean
 _glade_integer_handled_accumulator (GSignalInvocationHint *ihint,
-				    GValue *return_accu,
-				    const GValue *handler_return,
-				    gpointer dummy)
+                                    GValue                *return_accu,
+                                    const GValue          *handler_return,
+                                    gpointer              dummy)
 {
   gboolean continue_emission;
   gint retval;
@@ -59,9 +60,9 @@ _glade_integer_handled_accumulator (GSignalInvocationHint *ihint,
 /* From gtkmain.c */
 gboolean
 _glade_boolean_handled_accumulator (GSignalInvocationHint *ihint,
-				    GValue *return_accu,
-				    const GValue *handler_return,
-				    gpointer dummy)
+                                    GValue *return_accu,
+                                    const GValue *handler_return,
+                                    gpointer dummy)
 {
   gboolean continue_emission;
   gboolean signal_handled;
@@ -75,8 +76,9 @@ _glade_boolean_handled_accumulator (GSignalInvocationHint *ihint,
 
 gboolean
 _glade_string_accumulator (GSignalInvocationHint *ihint,
-			   GValue *return_accu,
-			   const GValue *handler_return, gpointer dummy)
+                           GValue                *return_accu,
+                           const GValue          *handler_return,
+                           gpointer               dummy)
 {
   const gchar *handler_str;
 
@@ -103,8 +105,9 @@ _glade_strv_handled_accumulator (GSignalInvocationHint *ihint,
 
 gboolean
 _glade_stop_emission_accumulator (GSignalInvocationHint *ihint,
-				  GValue *return_accu,
-				  const GValue *handler_return, gpointer dummy)
+                                  GValue                *return_accu,
+                                  const GValue          *handler_return,
+                                  gpointer               dummy)
 {
   g_value_copy (handler_return, return_accu);
 
