@@ -79,7 +79,7 @@ enum
 
 static guint adaptor_chooser_signals[LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (_GladeAdaptorChooserWidget, _glade_adaptor_chooser_widget, GTK_TYPE_BOX);
+G_DEFINE_TYPE_WITH_PRIVATE (_GladeAdaptorChooserWidget, _glade_adaptor_chooser_widget, GTK_TYPE_BOX)
 
 #define GET_PRIVATE(d) ((_GladeAdaptorChooserWidgetPrivate *) _glade_adaptor_chooser_widget_get_instance_private((_GladeAdaptorChooserWidget*)d))
 
@@ -89,13 +89,20 @@ _glade_adaptor_chooser_widget_init (_GladeAdaptorChooserWidget *chooser)
   gtk_widget_init_template (GTK_WIDGET (chooser));
 }
 
+static void
+_glade_adaptor_chooser_widget_dispose (GObject *object)
+{
+  _glade_adaptor_chooser_widget_set_project (GLADE_ADAPTOR_CHOOSER_WIDGET (object), NULL);
+
+  G_OBJECT_CLASS (_glade_adaptor_chooser_widget_parent_class)->dispose (object);
+}
+
 static void
 _glade_adaptor_chooser_widget_finalize (GObject *object)
 {
   _GladeAdaptorChooserWidgetPrivate *priv = GET_PRIVATE (object);
 
   g_clear_pointer (&priv->search_text, g_free);
-  g_clear_object (&priv->project);
 
   G_OBJECT_CLASS (_glade_adaptor_chooser_widget_parent_class)->finalize (object);
 }
@@ -513,6 +520,7 @@ _glade_adaptor_chooser_widget_class_init (_GladeAdaptorChooserWidgetClass *klass
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
+  object_class->dispose = _glade_adaptor_chooser_widget_dispose;
   object_class->finalize = _glade_adaptor_chooser_widget_finalize;
   object_class->set_property = _glade_adaptor_chooser_widget_set_property;
   object_class->get_property = _glade_adaptor_chooser_widget_get_property;
@@ -583,12 +591,19 @@ _glade_adaptor_chooser_widget_set_project (_GladeAdaptorChooserWidget *chooser,
   g_return_if_fail (GLADE_IS_ADAPTOR_CHOOSER_WIDGET (chooser));
   priv = GET_PRIVATE (chooser);
 
-  g_clear_object (&priv->project);
+  if (priv->project)
+    {
+      g_object_remove_weak_pointer (G_OBJECT (priv->project), (gpointer *) &priv->project);
+      priv->project = NULL;
+    }
 
   if (project)
-    priv->project = g_object_ref (project);
+    {
+      priv->project = project;
+      g_object_add_weak_pointer (G_OBJECT (project), (gpointer *) &priv->project);
 
-  gtk_tree_model_filter_refilter (priv->treemodelfilter);
+      gtk_tree_model_filter_refilter (priv->treemodelfilter);
+    }
 }
 
 void
