@@ -140,7 +140,7 @@ glade_command_class_init (GladeCommandClass *klass)
 /* Macros for defining the derived command types */
 #define GLADE_MAKE_COMMAND(type, func, upper_type)                   \
 G_DECLARE_FINAL_TYPE (type, func, GLADE, upper_type, GladeCommand)   \
-G_DEFINE_TYPE (type, func, GLADE_TYPE_COMMAND);                      \
+G_DEFINE_TYPE (type, func, GLADE_TYPE_COMMAND)                       \
 static gboolean                                                      \
 func ## _undo (GladeCommand *me);                                    \
 static gboolean                                                      \
@@ -342,7 +342,7 @@ struct _GladeCommandPropertyEnabled
 
 /* standard macros */
 #define GLADE_TYPE_COMMAND_PROPERTY_ENABLED glade_command_property_enabled_get_type ()
-GLADE_MAKE_COMMAND (GladeCommandPropertyEnabled, glade_command_property_enabled, COMMAND_PROPERTY_ENABLED);
+GLADE_MAKE_COMMAND (GladeCommandPropertyEnabled, glade_command_property_enabled, COMMAND_PROPERTY_ENABLED)
 
 static gboolean
 glade_command_property_enabled_execute (GladeCommand *cmd)
@@ -373,7 +373,7 @@ glade_command_property_enabled_finalize (GObject *obj)
 
   me = GLADE_COMMAND_PROPERTY_ENABLED (obj);
 
-  g_object_unref (me->property);
+  g_clear_object (&me->property);
   glade_command_finalize (obj);
 }
 
@@ -517,7 +517,7 @@ struct _GladeCommandSetProperty
 
 /* standard macros */
 #define GLADE_TYPE_COMMAND_SET_PROPERTY glade_command_set_property_get_type ()
-GLADE_MAKE_COMMAND (GladeCommandSetProperty, glade_command_set_property, COMMAND_SET_PROPERTY);
+GLADE_MAKE_COMMAND (GladeCommandSetProperty, glade_command_set_property, COMMAND_SET_PROPERTY)
 
 /* Undo the last "set property command" */
 static gboolean
@@ -963,7 +963,7 @@ struct _GladeCommandSetName
 
 /* standard macros */
 #define GLADE_TYPE_COMMAND_SET_NAME glade_command_set_name_get_type ()
-GLADE_MAKE_COMMAND (GladeCommandSetName, glade_command_set_name, COMMAND_SET_NAME);
+GLADE_MAKE_COMMAND (GladeCommandSetName, glade_command_set_name, COMMAND_SET_NAME)
 
 /* Undo the last "set name command" */
 static gboolean
@@ -1114,7 +1114,7 @@ struct _GladeCommandAddRemove
 };
 
 #define GLADE_TYPE_COMMAND_ADD_REMOVE glade_command_add_remove_get_type ()
-GLADE_MAKE_COMMAND (GladeCommandAddRemove, glade_command_add_remove, COMMAND_ADD_REMOVE);
+GLADE_MAKE_COMMAND (GladeCommandAddRemove, glade_command_add_remove, COMMAND_ADD_REMOVE)
 
 static void
 glade_command_placeholder_destroyed (GtkWidget *object, CommandData *cdata)
@@ -1240,7 +1240,7 @@ glade_command_add (GList            *widgets,
       /* Parentless ref */
       if ((cdata->reffed =
            get_all_parentless_reffed_widgets (cdata->reffed, widget)) != NULL)
-        g_list_foreach (cdata->reffed, (GFunc) g_object_ref, NULL);
+        glade_util_list_objects_ref (cdata->reffed);
 
       /* Parent */
       if (parent == NULL)
@@ -1410,7 +1410,7 @@ glade_command_remove (GList *widgets)
 
       if ((cdata->reffed =
            get_all_parentless_reffed_widgets (cdata->reffed, widget)) != NULL)
-        g_list_foreach (cdata->reffed, (GFunc) g_object_ref, NULL);
+        glade_util_list_objects_ref (cdata->reffed);
 
       /* If we're removing the template widget, then we need to unset it as template */
       if (glade_project_get_template (priv->project) == widget)
@@ -1541,10 +1541,7 @@ glade_command_add_execute (GladeCommandAddRemove *me)
               glade_command_transfer_props (cdata->widget, saved_props);
 
               if (saved_props)
-                {
-                  g_list_foreach (saved_props, (GFunc) g_object_unref, NULL);
-                  g_list_free (saved_props);
-                }
+                g_list_free_full (saved_props, g_object_unref);
 
               /* Now that we've added, apply any packing props if nescisary. */
               for (l = cdata->pack_props; l; l = l->next)
@@ -1713,36 +1710,35 @@ glade_command_add_remove_undo (GladeCommand *cmd)
   return glade_command_add_remove_execute (cmd);
 }
 
+static void
+glade_command_data_free (gpointer data)
+{
+  CommandData *cdata = data;
+
+  if (cdata->placeholder)
+    {
+      g_clear_signal_handler (&cdata->handler_id, cdata->placeholder);
+
+      if (g_object_is_floating (G_OBJECT (cdata->placeholder)))
+        gtk_widget_destroy (GTK_WIDGET (cdata->placeholder));
+    }
+
+  g_clear_object (&cdata->widget);
+  g_list_free_full (cdata->reffed, g_object_unref);
+
+  g_free (cdata);
+}
+
 static void
 glade_command_add_remove_finalize (GObject *obj)
 {
   GladeCommandAddRemove *cmd;
-  CommandData *cdata;
-  GList *list;
 
   g_return_if_fail (GLADE_IS_COMMAND_ADD_REMOVE (obj));
 
   cmd = GLADE_COMMAND_ADD_REMOVE (obj);
 
-  for (list = cmd->widgets; list && list->data; list = list->next)
-    {
-      cdata = list->data;
-
-      if (cdata->placeholder)
-        {
-          if (cdata->handler_id)
-            g_signal_handler_disconnect (cdata->placeholder, cdata->handler_id);
-          if (g_object_is_floating (G_OBJECT (cdata->placeholder)))
-            gtk_widget_destroy (GTK_WIDGET (cdata->placeholder));
-        }
-
-      if (cdata->widget)
-        g_object_unref (G_OBJECT (cdata->widget));
-
-      g_list_foreach (cdata->reffed, (GFunc) g_object_unref, NULL);
-      g_list_free (cdata->reffed);
-    }
-  g_list_free (cmd->widgets);
+  g_list_free_full (cmd->widgets, glade_command_data_free);
 
   glade_command_finalize (obj);
 }
@@ -2042,19 +2038,16 @@ struct _GladeCommandAddSignal
 
 /* standard macros */
 #define GLADE_TYPE_COMMAND_ADD_SIGNAL glade_command_add_signal_get_type ()
-GLADE_MAKE_COMMAND (GladeCommandAddSignal, glade_command_add_signal, COMMAND_ADD_SIGNAL);
+GLADE_MAKE_COMMAND (GladeCommandAddSignal, glade_command_add_signal, COMMAND_ADD_SIGNAL)
 
 static void
 glade_command_add_signal_finalize (GObject *obj)
 {
   GladeCommandAddSignal *cmd = GLADE_COMMAND_ADD_SIGNAL (obj);
 
-  g_object_unref (cmd->widget);
-
-  if (cmd->signal)
-    g_object_unref (cmd->signal);
-  if (cmd->new_signal)
-    g_object_unref (cmd->new_signal);
+  g_clear_object (&cmd->widget);
+  g_clear_object (&cmd->signal);
+  g_clear_object (&cmd->new_signal);
 
   glade_command_finalize (obj);
 }
@@ -2211,7 +2204,7 @@ struct _GladeCommandSetI18n
 };
 
 #define GLADE_TYPE_COMMAND_SET_I18N glade_command_set_i18n_get_type ()
-GLADE_MAKE_COMMAND (GladeCommandSetI18n, glade_command_set_i18n, COMMAND_SET_I18N);
+GLADE_MAKE_COMMAND (GladeCommandSetI18n, glade_command_set_i18n, COMMAND_SET_I18N)
 
 static gboolean
 glade_command_set_i18n_execute (GladeCommand *cmd)
@@ -2710,7 +2703,7 @@ struct _GladeCommandProperty
 };
 
 #define GLADE_TYPE_COMMAND_PROPERTY glade_command_property_get_type ()
-GLADE_MAKE_COMMAND (GladeCommandProperty, glade_command_property, COMMAND_PROPERTY);
+GLADE_MAKE_COMMAND (GladeCommandProperty, glade_command_property, COMMAND_PROPERTY)
 
 /* Return true if a == b, this could be exported in glade_utils */
 static gboolean
