@@ -826,6 +826,7 @@ glade_signal_editor_dispose (GObject *object)
   GladeSignalEditor *editor = GLADE_SIGNAL_EDITOR (object);
   GladeSignalEditorPrivate *priv = glade_signal_editor_get_instance_private (editor);
 
+  g_clear_object (&priv->widget);
   g_clear_object (&priv->detail_store);
   g_clear_object (&priv->handler_store);
   
@@ -1359,7 +1360,7 @@ glade_signal_editor_init (GladeSignalEditor *self)
                                   NULL);
 
   renderer = glade_cell_renderer_icon_new ();
-  g_object_set (G_OBJECT (renderer), "icon-name", "gtk-edit", NULL);
+  g_object_set (G_OBJECT (renderer), "icon-name", "document-edit-symbolic", NULL);
 
   g_signal_connect (G_OBJECT (renderer), "activate",
                     G_CALLBACK (glade_signal_editor_user_data_activate),
@@ -1424,7 +1425,7 @@ glade_signal_editor_init (GladeSignalEditor *self)
         g_object_set (G_OBJECT (renderer), "icon-name", GLADE_DEVHELP_ICON_NAME,
                       NULL);
       else
-        g_object_set (G_OBJECT (renderer), "icon-name", "dialog-information", NULL);
+        g_object_set (G_OBJECT (renderer), "icon-name", "dialog-information-symbolic", NULL);
 
       g_signal_connect (G_OBJECT (renderer), "activate",
                         G_CALLBACK (glade_signal_editor_devhelp), self);
