@@ -65,9 +65,9 @@ struct _GladeXmlContext
   xmlNsPtr ns;
 };
 
-G_DEFINE_BOXED_TYPE(GladeXmlNode, glade_xml_node, glade_xml_node_copy, glade_xml_node_delete);
-G_DEFINE_BOXED_TYPE(GladeXmlDoc, glade_xml_doc, glade_xml_doc_ref, glade_xml_doc_unref);
-G_DEFINE_BOXED_TYPE(GladeXmlContext, glade_xml_context, glade_xml_context_copy, glade_xml_context_free);
+G_DEFINE_BOXED_TYPE(GladeXmlNode, glade_xml_node, glade_xml_node_copy, glade_xml_node_delete)
+G_DEFINE_BOXED_TYPE(GladeXmlDoc, glade_xml_doc, glade_xml_doc_ref, glade_xml_doc_unref)
+G_DEFINE_BOXED_TYPE(GladeXmlContext, glade_xml_context, glade_xml_context_copy, glade_xml_context_free)
 
 static GladeXmlDoc *glade_xml_doc_new_from_doc (xmlDocPtr docptr);
 
@@ -857,6 +857,13 @@ glade_xml_node_is_comment (GladeXmlNode *node_in)
   return (node) ? node->type == XML_COMMENT_NODE : FALSE;
 }
 
+static inline gboolean
+glade_xml_node_is_text (GladeXmlNode *node_in)
+{
+  xmlNodePtr node = (xmlNodePtr) node_in;
+  return (node) ? node->type == XML_TEXT_NODE : FALSE;
+}
+
 static inline gboolean
 glade_xml_node_is_comment_or_text (GladeXmlNode *node_in)
 {
@@ -911,7 +918,11 @@ glade_xml_node_next_with_comments (GladeXmlNode *node_in)
 {
   xmlNodePtr node = (xmlNodePtr) node_in;
 
-  return (GladeXmlNode *) node->next;
+  node = node->next;
+  while (glade_xml_node_is_text ((GladeXmlNode *) node))
+    node = node->next;
+
+  return (GladeXmlNode *) node;
 }
 
 GladeXmlNode *
@@ -919,7 +930,11 @@ glade_xml_node_prev_with_comments (GladeXmlNode *node_in)
 {
   xmlNodePtr node = (xmlNodePtr) node_in;
 
-  return (GladeXmlNode *) node->prev;
+  node = node->prev;
+  while (glade_xml_node_is_text ((GladeXmlNode *) node))
+    node = node->prev;
+
+  return (GladeXmlNode *) node;
 }
 
 const gchar *
