@@ -77,7 +77,7 @@ static GladeEditableInterface *parent_editable_iface;
 G_DEFINE_TYPE_WITH_CODE (GladeButtonEditor, glade_button_editor, GLADE_TYPE_EDITOR_SKELETON,
                          G_ADD_PRIVATE (GladeButtonEditor)
                          G_IMPLEMENT_INTERFACE (GLADE_TYPE_EDITABLE,
-                                                glade_button_editor_editable_init));
+                                                glade_button_editor_editable_init))
 
 static void
 glade_button_editor_class_init (GladeButtonEditorClass * klass)
