@@ -83,7 +83,7 @@ static GladeEditableInterface *parent_editable_iface;
 G_DEFINE_TYPE_WITH_CODE (GladeEntryEditor, glade_entry_editor, GLADE_TYPE_EDITOR_SKELETON,
                          G_ADD_PRIVATE (GladeEntryEditor)
                          G_IMPLEMENT_INTERFACE (GLADE_TYPE_EDITABLE,
-                                                glade_entry_editor_editable_init));
+                                                glade_entry_editor_editable_init))
 
 static void
 glade_entry_editor_class_init (GladeEntryEditorClass * klass)
