@@ -413,10 +413,11 @@ glade_gtk_notebook_post_create (GladeWidgetAdaptor *adaptor,
   g_signal_connect (G_OBJECT (notebook), "switch-page",
                     G_CALLBACK (glade_gtk_notebook_switch_page), NULL);
 
-  if (reason == GLADE_CREATE_LOAD)
-    g_signal_connect (project, "parse-finished",
-                      G_CALLBACK (glade_gtk_notebook_parse_finished),
-                      notebook);
+  if (project && glade_project_is_loading (project))
+    g_signal_connect_object (project, "parse-finished",
+                             G_CALLBACK (glade_gtk_notebook_parse_finished),
+                             notebook,
+                             0);
 }
 
 static gint
