@@ -49,7 +49,7 @@ static GladeEditableInterface *parent_editable_iface;
 G_DEFINE_TYPE_WITH_CODE (GladeImageEditor, glade_image_editor, GLADE_TYPE_EDITOR_SKELETON,
                          G_ADD_PRIVATE (GladeImageEditor)
                          G_IMPLEMENT_INTERFACE (GLADE_TYPE_EDITABLE,
-                                                glade_image_editor_editable_init));
+                                                glade_image_editor_editable_init))
 
 static void
 glade_image_editor_class_init (GladeImageEditorClass * klass)
