@@ -63,7 +63,7 @@ static GladeEditableInterface *parent_editable_iface;
 G_DEFINE_TYPE_WITH_CODE (GladeLabelEditor, glade_label_editor, GLADE_TYPE_EDITOR_SKELETON,
                          G_ADD_PRIVATE (GladeLabelEditor)
                          G_IMPLEMENT_INTERFACE (GLADE_TYPE_EDITABLE,
-                                                glade_label_editor_editable_init));
+                                                glade_label_editor_editable_init))
 
 static void
 glade_label_editor_class_init (GladeLabelEditorClass *klass)
