@@ -114,7 +114,7 @@ struct _GladeRegistrationPrivate
   GtkWidget *comments;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (GladeRegistration, glade_registration, GTK_TYPE_DIALOG);
+G_DEFINE_TYPE_WITH_PRIVATE (GladeRegistration, glade_registration, GTK_TYPE_DIALOG)
 
 enum 
 {
@@ -347,7 +347,7 @@ on_subscribe_http_request_done (GladeHTTP         *http,
             }
           else
             glade_registration_show_message (registration, GTK_MESSAGE_INFO, "%s",
-                                             _("Your subscription to the users list has been received!\nCheck you email!"));
+                                             _("Your subscription to the users list has been received!\nCheck your email!"));
         }
       break;
       default:
