@@ -14,9 +14,9 @@ typedef struct {
 /* Avoid warnings from GVFS-RemoteVolumeMonitor */
 static gboolean
 ignore_gvfs_warning (const gchar *log_domain,
-		     GLogLevelFlags log_level,
-		     const gchar *message,
-		     gpointer user_data)
+                     GLogLevelFlags log_level,
+                     const gchar *message,
+                     gpointer user_data)
 {
   if (g_strcmp0 (log_domain, "GVFS-RemoteVolumeMonitor") == 0)
     return FALSE;
@@ -24,17 +24,9 @@ ignore_gvfs_warning (const gchar *log_domain,
   return TRUE;
 }
 
-static gboolean
-main_loop_quit_cb (gpointer data)
-{
-  gtk_main_quit ();
-
-  return FALSE;
-}
-
 static void
 check_finalized (gpointer data,
-		 GObject *where_the_object_was)
+                 GObject *where_the_object_was)
 {
   gboolean *did_finalize = (gboolean *)data;
 
@@ -70,24 +62,11 @@ test_add_child (gconstpointer data)
   /* Pass ownership to the parent */
   g_object_unref (gchild);
 
-  g_assert (glade_widget_get_parent (gchild) == gparent);
+  g_assert_true (glade_widget_get_parent (gchild) == gparent);
 
   if (test->func)
     test->func (parent, child);
 
-  /* filechoosers hold a reference until an async operation is complete */
-  if (GTK_IS_FILE_CHOOSER (parent) || GTK_IS_FILE_CHOOSER (child))
-    {
-      g_timeout_add (2000, main_loop_quit_cb, NULL);
-      gtk_main();
-    }
-  /* Our plugin code adds an idle when cell renderers are created */
-  else if (GTK_IS_CELL_RENDERER (child))
-    {
-      g_timeout_add (50, main_loop_quit_cb, NULL);
-      gtk_main();
-    }
-
   /* Unreffing the parent should finalize the parent and child runtime objects */
   g_object_weak_ref (G_OBJECT (gparent), check_finalized, &gparent_finalized);
   g_object_weak_ref (G_OBJECT (gchild),  check_finalized, &gchild_finalized);
@@ -96,23 +75,23 @@ test_add_child (gconstpointer data)
 
   g_object_unref (gparent);
 
-  g_assert (gparent_finalized);
-  g_assert (gchild_finalized);
-  g_assert (parent_finalized);
-  g_assert (child_finalized);
+  g_assert_true (gparent_finalized);
+  g_assert_true (gchild_finalized);
+  g_assert_true (parent_finalized);
+  g_assert_true (child_finalized);
 }
 
 static void
 add_test (GType parent_type,
-	  GType child_type,
-	  AssertParentedFunc func)
+          GType child_type,
+          AssertParentedFunc func)
 {
   gchar *test_path;
   TestData *data = g_new (TestData, 1);
 
   test_path = g_strdup_printf ("/AddChild/%s/%s",
-			       g_type_name (parent_type),
-			       g_type_name (child_type));
+                               g_type_name (parent_type),
+                               g_type_name (child_type));
 
   data->parent_type = parent_type;
   data->child_type  = child_type;
@@ -124,39 +103,40 @@ add_test (GType parent_type,
 
 static void
 assert_widget_parented (GObject *parent,
-			GObject *child)
+                        GObject *child)
 {
-  g_assert (gtk_widget_get_parent (GTK_WIDGET (child)) == GTK_WIDGET (parent));
+  g_assert_true (gtk_widget_get_parent (GTK_WIDGET (child)) == GTK_WIDGET (parent) ||
+                 G_OBJECT (gtk_widget_get_ancestor (GTK_WIDGET (child), G_OBJECT_TYPE (parent))) == parent);
 }
 
 static void
 assert_submenu (GObject *parent,
-		GObject *child)
+                GObject *child)
 {
   if (GTK_IS_MENU_ITEM (parent))
-    g_assert (gtk_menu_item_get_submenu (GTK_MENU_ITEM (parent)) == GTK_WIDGET (child));
+    g_assert_true (gtk_menu_item_get_submenu (GTK_MENU_ITEM (parent)) == GTK_WIDGET (child));
   else if (GTK_IS_MENU_TOOL_BUTTON (parent))
-    g_assert (gtk_menu_tool_button_get_menu (GTK_MENU_TOOL_BUTTON (parent)) == GTK_WIDGET (child));
+    g_assert_true (gtk_menu_tool_button_get_menu (GTK_MENU_TOOL_BUTTON (parent)) == GTK_WIDGET (child));
   else
-    g_assert_not_reached ();
+    g_assert_true (FALSE);
 }
 
 static void
 assert_cell_parented (GObject *parent,
-		      GObject *child)
+                      GObject *child)
 {
   GList *cells;
 
   cells = gtk_cell_layout_get_cells (GTK_CELL_LAYOUT (parent));
-  g_assert (g_list_find (cells, child) != NULL);
+  g_assert_true (g_list_find (cells, child) != NULL);
   g_list_free (cells);
 }
 
 static void
 assert_column_parented (GObject *parent,
-			GObject *child)
+                        GObject *child)
 {
-  g_assert (gtk_tree_view_get_column (GTK_TREE_VIEW (parent), 0) == GTK_TREE_VIEW_COLUMN (child));
+  g_assert_true (gtk_tree_view_get_column (GTK_TREE_VIEW (parent), 0) == GTK_TREE_VIEW_COLUMN (child));
 }
 
 /* Ignore deprecated classes, we test them regardless */
@@ -194,8 +174,7 @@ add_child_widgets (GType parent_type)
   add_test (parent_type, GTK_TYPE_FONT_BUTTON,         assert_widget_parented);
   add_test (parent_type, GTK_TYPE_COLOR_BUTTON,        assert_widget_parented);
 
-  /* FIXME: FileChooserButton leaks a GTask which will crash in the following test */
-  /* add_test (parent_type, GTK_TYPE_FILE_CHOOSER_BUTTON, assert_widget_parented); */
+  add_test (parent_type, GTK_TYPE_FILE_CHOOSER_BUTTON, assert_widget_parented);
   add_test (parent_type, GTK_TYPE_APP_CHOOSER_BUTTON,  assert_widget_parented);
   add_test (parent_type, GTK_TYPE_TEXT_VIEW,           assert_widget_parented);
   add_test (parent_type, GTK_TYPE_TREE_VIEW,           assert_widget_parented);
@@ -247,9 +226,13 @@ main (int   argc,
 
   /* Normal GtkContainer / GtkWidget parenting */
   add_child_widgets (GTK_TYPE_WINDOW);
+  add_child_widgets (GTK_TYPE_OFFSCREEN_WINDOW);
+  add_child_widgets (GTK_TYPE_APPLICATION_WINDOW);
   add_child_widgets (GTK_TYPE_BOX);
   add_child_widgets (GTK_TYPE_GRID);
   add_child_widgets (GTK_TYPE_NOTEBOOK);
+  //add_child_widgets (GTK_TYPE_FRAME);
+  add_child_widgets (GTK_TYPE_ASPECT_FRAME);
   add_child_widgets (GTK_TYPE_OVERLAY);
   add_child_widgets (GTK_TYPE_PANED);
   add_child_widgets (GTK_TYPE_BUTTON_BOX);
@@ -259,6 +242,24 @@ main (int   argc,
   add_child_widgets (GTK_TYPE_EXPANDER);
   add_child_widgets (GTK_TYPE_VIEWPORT);
   add_child_widgets (GTK_TYPE_ALIGNMENT);
+  add_child_widgets (GTK_TYPE_STACK);
+  add_child_widgets (GTK_TYPE_REVEALER);
+  add_child_widgets (GTK_TYPE_POPOVER);
+  add_child_widgets (GTK_TYPE_HEADER_BAR);
+  add_child_widgets (GTK_TYPE_ACTION_BAR);
+  add_child_widgets (GTK_TYPE_SEARCH_BAR);
+  //add_child_widgets (GTK_TYPE_POPOVER_MENU);
+
+  /* Scrolled window */
+  add_test (GTK_TYPE_SCROLLED_WINDOW, GTK_TYPE_ICON_VIEW, assert_widget_parented);
+  add_test (GTK_TYPE_SCROLLED_WINDOW, GTK_TYPE_LAYOUT, assert_widget_parented);
+  add_test (GTK_TYPE_SCROLLED_WINDOW, GTK_TYPE_TEXT_VIEW, assert_widget_parented);
+  add_test (GTK_TYPE_SCROLLED_WINDOW, GTK_TYPE_TOOL_PALETTE, assert_widget_parented);
+  add_test (GTK_TYPE_SCROLLED_WINDOW, GTK_TYPE_TREE_VIEW, assert_widget_parented);
+  add_test (GTK_TYPE_SCROLLED_WINDOW, GTK_TYPE_VIEWPORT, assert_widget_parented);
+
+  add_test (GTK_TYPE_LIST_BOX, GTK_TYPE_LIST_BOX_ROW, assert_widget_parented);
+  add_test (GTK_TYPE_FLOW_BOX, GTK_TYPE_FLOW_BOX_CHILD, assert_widget_parented);
 
   /* Actions */
   add_test (GTK_TYPE_ACTION_GROUP, GTK_TYPE_ACTION, NULL);
